pub struct Agent {Show 16 fields
pub id: String,
pub provider: Provider,
pub system_instruction: Vec<MessageNum>,
pub tools: Arc<RwLock<ToolRegistry>>,
pub max_iterations: u32,
pub run_config: Option<AgentRunConfig>,
pub model_override: Option<String>,
pub criteria: Vec<Box<dyn CompletionCriteria>>,
pub callbacks: Vec<Arc<dyn AgentCallback>>,
pub memory: Option<Arc<Mutex<Box<dyn Memory>>>>,
pub app_name: Option<String>,
pub user_id: Option<String>,
pub session_id: Option<String>,
pub session_store: Option<Arc<dyn SessionStore>>,
pub user_state_store: Option<Arc<dyn UserStateStore>>,
pub app_state_store: Option<Arc<dyn AppStateStore>>,
/* private fields */
}Fields
id: Stringprovider: Providersystem_instruction: Vec<MessageNum>tools: Arc<RwLock<ToolRegistry>>max_iterations: u32run_config: Option<AgentRunConfig>model_override: Option<String>If set, overrides the model in any Prompt built by AgentBuilder::run().
criteria: Vec<Box<dyn CompletionCriteria>>callbacks: Vec<Arc<dyn AgentCallback>>memory: Option<Arc<Mutex<Box<dyn Memory>>>>app_name: Option<String>Application name used for store scoping.
user_id: Option<String>User identifier used for store scoping.
session_id: Option<String>Session identifier used to key store lookups.
session_store: Option<Arc<dyn SessionStore>>Optional durable session state store.
user_state_store: Option<Arc<dyn UserStateStore>>Optional per-user state store.
app_state_store: Option<Arc<dyn AppStateStore>>Optional app-level state store.
Implementations
Sourceimpl Agent
Rust method implementation of the Agent
impl Agent
Rust method implementation of the Agent
Sourcepub async fn rebuild_client(&self) -> Result<Agent, AgentError>
pub async fn rebuild_client(&self) -> Result<Agent, AgentError>
Helper method to rebuild the client, useful for deserialization
pub async fn new( provider: Provider, system_instruction: Option<Vec<MessageNum>>, ) -> Result<Agent, AgentError>
pub fn register_tool(&self, tool: Box<dyn Tool + Sync + Send>)
pub async fn execute_task( &self, task: &Task, ) -> Result<AgentResponse, AgentError>
pub async fn execute_prompt( &self, prompt: &Prompt, ) -> Result<AgentResponse, AgentError>
Sourcepub async fn execute_task_with_context(
&self,
task: &Arc<RwLock<Task>>,
context: &Value,
) -> Result<AgentResponse, AgentError>
pub async fn execute_task_with_context( &self, task: &Arc<RwLock<Task>>, context: &Value, ) -> Result<AgentResponse, AgentError>
Execute task with context without mutating the original task This method is used by the workflow executor to run individual tasks with context
pub async fn execute_task_with_context_message( &self, task: &Arc<RwLock<Task>>, context_messages: HashMap<String, Vec<MessageNum>>, parameter_context: Value, global_context: Option<Arc<Value>>, ) -> Result<AgentResponse, AgentError>
pub fn client_provider(&self) -> &Provider