pub struct PyAgent {
pub agent: Arc<Agent>,
pub runtime: Arc<Runtime>,
}Fields
agent: Arc<Agent>runtime: Arc<Runtime>Implementations
Sourceimpl PyAgent
impl PyAgent
Sourcepub fn new(
provider: &Bound<'_, PyAny>,
system_instruction: Option<&Bound<'_, PyAny>>,
) -> Result<PyAgent, AgentError>
pub fn new( provider: &Bound<'_, PyAny>, system_instruction: Option<&Bound<'_, PyAny>>, ) -> Result<PyAgent, AgentError>
Creates a new Agent instance.
Arguments:
provider- A Python object representing the provider, expected to be an a variant of Provider or a string that can be mapped to a provider variant
pub fn execute_task( &self, py: Python<'_>, task: &mut Task, output_type: Option<Bound<'_, PyAny>>, model: Option<&str>, ) -> Result<PyAgentResponse, AgentError>
pub fn execute_prompt( &self, py: Python<'_>, prompt: &mut Prompt, output_type: Option<Bound<'_, PyAny>>, model: Option<&str>, ) -> Result<PyAgentResponse, AgentError>
pub fn system_instruction<'py>( &self, py: Python<'py>, ) -> Result<Bound<'py, PyAny>, AgentError>
pub fn id(&self) -> &str