potato_
workflow
0.2.2
Module flow
Module Items
Structs
Enums
Functions
In potato_
workflow::
workflow
potato_workflow
::
workflow
Module
flow
Structs

Agent
PyTask
Task
Task
List
Workflow
Rust-specific implementation of a workflow
Workflow
Result
Enums

Chat
Response
Task
Status
Functions

execute_
workflow
Execute the workflow asynchronously This function will be called to start the workflow execution process and does the following: